@@ -18,6 +18,9 @@ class PolysynthException(Exception):
     def __str__(self):
         return Response(self._status_code, self._err_code, self._err_msg, self._data).__str__()
 
+    def __dict__(self):
+        return Response(self._status_code, self._err_code, self._err_msg, self._data).__dict__()
+
 class MissingInputError(PolysynthException): pass
 
 class InvalidFormatError(PolysynthException): pass
@@ -38,7 +41,9 @@ class LowGasError(PolysynthException): pass
 
 class TransactionFailedError(PolysynthException): pass
 
+class TransactionTimedOut(PolysynthException): pass
 
+class NoPositionsOpen(PolysynthException): pass
 
 
 
